summaryrefslogtreecommitdiffstats
path: root/kexi/widget/tableview/kexitextformatter.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/widget/tableview/kexitextformatter.h')
-rw-r--r--kexi/widget/tableview/kexitextformatter.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/kexi/widget/tableview/kexitextformatter.h b/kexi/widget/tableview/kexitextformatter.h
index 3ea611a44..12e67a37e 100644
--- a/kexi/widget/tableview/kexitextformatter.h
+++ b/kexi/widget/tableview/kexitextformatter.h
@@ -22,7 +22,7 @@
#include <kexidb/field.h>
//! @short Text formatter used to format QVariant values to text for displaying and back to QVariant
/*! Used by KexiInputTableEdit, KexiDateTableEdit, KexiTimeTableEdit, KexiDateTimeTableEdit,
KexiDBLineEdit (forms), etc. */
class KEXIDATATABLE_EXPORT KexiTextFormatter
@@ -38,24 +38,24 @@ class KEXIDATATABLE_EXPORT KexiTextFormatter
A field schema set using setField() is used to perform the formatting.
\a add is a text that should be added to the value if possible.
Used in KexiInputTableEdit::setValueInternal(), by form widgets and for reporting/printing. */
- QString valueToText(const QVariant& value, const QString& add) const;
+ TQString valueToText(const TQVariant& value, const TQString& add) const;
/*! \return value cnverted from \a text
A field schema set using setField() is used to perform the formatting.
Used in KexiInputTableEdit::setValueInternal(), by form widgets and for reporting/printing. */
- QVariant textToValue(const QString& text) const;
+ TQVariant textToValue(const TQString& text) const;
/*! \return true if value formatted as \a text is empty.
A field schema set using setField() is used to perform the calculation. */
- bool valueIsEmpty(const QString& text) const;
+ bool valueIsEmpty(const TQString& text) const;
/*! \return true if value formatted as \a text is valid.
A field schema set using setField() is used to perform the calculation. */
- bool valueIsValid(const QString& text) const;
+ bool valueIsValid(const TQString& text) const;
- /*! \return input mask for intering values related to a field schema
+ /*! \return input tqmask for intering values related to a field schema
which has been set using setField(). */
- QString inputMask() const;
+ TQString inputMask() const;
class Private;
Private *d;
@@ -22,7 +22,7 @@
#include <kexidb/field.h>
-//! @short Text formatter used to format QVariant values to text for displaying and back to QVariant
+//! @short Text formatter used to format TQVariant values to text for displaying and back to TQVariant
/*! Used by KexiInputTableEdit, KexiDateTableEdit, KexiTimeTableEdit, KexiDateTimeTableEdit,
KexiDBLineEdit (forms), etc. */